local core = CalendarExtras

local module = core:NewModule("Invite")

 --[[ ------- Locals -------- ]]--

local frame
local whoToInvite = {}
local max
local isInviting

 --[[ ---- Inviter-frame ---- ]]--

do
	frame = CreateFrame("frame")
	frame:Hide()
	frame:SetHeight(60)
	frame:SetWidth(120)
	frame:SetBackdrop({
		bgFile = [[Interface\Tooltips\UI-Tooltip-Background]],
		edgeFile = [[Interface\Tooltips\UI-Tooltip-Border]],
		insets = {left = 3, right = 3, top = 3, bottom = 3},
		edgeSize = 12, --tileSize = 1,
		tile = false,
	})
	frame:SetBackdropColor(0, 0, 0, 1)

	local statusBar = CreateFrame("statusbar", nil, frame)
	frame.bar = statusBar
	statusBar:SetHeight(14)
	statusBar:SetWidth(105)
	statusBar:SetPoint("CENTER", 0, 3)
	statusBar:SetStatusBarTexture([[Interface\PaperDollInfoFrame\UI-Character-Skills-Bar]])
	statusBar:SetStatusBarColor(0, 1, 0)
	statusBar:GetRegions():SetDrawLayer("BORDER") -- Can this ever return anything but the actual statusbar texture with the SetDrawLayer-method?

	local barText = statusBar:CreateFontString(nil, "ARTWORK", "GameFontWhiteTiny")
	statusBar.text = barText
	barText:SetPoint("CENTER")
	barText:SetJustifyH("CENTER")

	local border = statusBar:CreateTexture(nil, "ARTWORK")
	border:SetHeight(30)
	border:SetWidth(110)
	border:SetPoint("CENTER")
	border:SetTexture([[Interface\PaperDollInfoFrame\UI-Character-Skills-BarBorder]])

	local spark = statusBar:CreateTexture(nil, "OVERLAY")
	statusBar.spark = spark
	spark:SetWidth(32)
	spark:SetHeight(32)
	spark:SetTexture([[Interface\CastingBar\UI-CastingBar-Spark]])
	spark:SetBlendMode("ADD")

	local bg = statusBar:CreateTexture(nil, "BACKGROUND")
	bg:SetAllPoints()
	bg:SetTexture(1, 1, 1, 0.2)

	local textLeft = frame:CreateFontString(nil, "ARTWORK", "GameFontWhiteSmall")
	textLeft:SetFont(STANDARD_TEXT_FONT, 10)
	textLeft:SetPoint("TOPLEFT", 5, -5)
	textLeft:SetText("Inviting:")

	local textRight = frame:CreateFontString(nil, "ARTWORK")
	textRight:SetFont(textLeft:GetFont())
	frame.textRight = textRight
	textRight:SetPoint("TOPRIGHT", -5, -5)
	textRight:SetPoint("LEFT", textLeft, "RIGHT")
	textRight:SetJustifyH("RIGHT")

	local stopButton = CreateFrame("button", nil, frame, "UIPanelButtonTemplate")
	frame.stopButton = stopButton
	stopButton:SetWidth(70)
	stopButton:SetHeight(20)
	stopButton:SetPoint("BOTTOM", 0, 5)
	stopButton:SetText("Stop")
	stopButton:SetScript("OnClick", function(self, button) frame:Hide() end)
end

function frame:SetProgress(k, name)
	k = k == 0 and k or k - 1
	if name then
	self.textRight:SetText(core:ColorByClass(name))
	else
		self.textRight:SetText("")
	end

	self.bar:SetValue(k)
	self.bar.text:SetText(k.." / "..max)

	if k ~= 0 and k ~= max then
		self.bar.spark:Show()
		self.bar.spark:SetPoint("CENTER", self.bar, "LEFT", (k / max) * self.bar:GetWidth(), 2)
	else
		self.bar.spark:Hide()
	end
end

frame:SetScript("OnUpdate", function(self)
	if CalendarCanSendInvite() then
		local k, name = next(whoToInvite, self.lastIndex)
		if name then
			CalendarEventInvite(name)
			self:SetProgress(k, name)
		else
			self:Hide()
		end
		self.lastIndex = k
	end
end)

frame:SetScript("OnHide", function(self)
	isInviting = nil
	whoToInvite = {}
	self:Hide()
end)

core.RegisterCallback(module, "OpenEvent", function() frame:Hide() end)

 --[[ ---------------------- ]]--

function module:Add(name)
	if not isInviting then
		tinsert(whoToInvite, name)
	end
end

function module:InviteArenaTeam(size)
	
end

function module:InviteByRank(rank)
	
end

function module:Invite()
	if isInviting then return end
	max = #whoToInvite
	if max == 0 then return end

	frame.bar:SetMinMaxValues(0, max)

	frame:SetProgress(0)

	if CalendarViewEventInviteList:IsVisible() then
		frame:SetParent(CalendarViewEventInviteList)
	else
		frame:SetParent(CalendarCreateEventInviteList)
	end
	frame:SetFrameStrata("DIALOG")
	frame:SetPoint("CENTER")

	frame:Show()
	isInviting = true
end